@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for emr service client paginators.
 
@@ -28,11 +29,12 @@ Usage::
     list_steps_paginator: ListStepsPaginator = client.get_paginator("list_steps")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from datetime import datetime
 import sys
-from typing import Iterator, List, TYPE_CHECKING
+from datetime import datetime
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_emr.type_defs import (
     ListBootstrapActionsOutputTypeDef,
     ListClustersOutputTypeDef,
@@ -63,20 +65,20 @@ __all__ = (
 
 class ListBootstrapActionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListBootstrapActions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListBootstrapActions)
+    [Paginator.ListBootstrapActions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListBootstrapActions)
     """
 
     def paginate(
         self, ClusterId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListBootstrapActionsOutputTypeDef]:
         """
-        [ListBootstrapActions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListBootstrapActions.paginate)
+        [ListBootstrapActions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListBootstrapActions.paginate)
         """
 
 
 class ListClustersPaginator(Boto3Paginator):
     """
-    [Paginator.ListClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListClusters)
+    [Paginator.ListClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListClusters)
     """
 
     def paginate(
@@ -97,39 +99,39 @@ class ListClustersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListClustersOutputTypeDef]:
         """
-        [ListClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListClusters.paginate)
+        [ListClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListClusters.paginate)
         """
 
 
 class ListInstanceFleetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListInstanceFleets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListInstanceFleets)
+    [Paginator.ListInstanceFleets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListInstanceFleets)
     """
 
     def paginate(
         self, ClusterId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListInstanceFleetsOutputTypeDef]:
         """
-        [ListInstanceFleets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListInstanceFleets.paginate)
+        [ListInstanceFleets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListInstanceFleets.paginate)
         """
 
 
 class ListInstanceGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.ListInstanceGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListInstanceGroups)
+    [Paginator.ListInstanceGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListInstanceGroups)
     """
 
     def paginate(
         self, ClusterId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListInstanceGroupsOutputTypeDef]:
         """
-        [ListInstanceGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListInstanceGroups.paginate)
+        [ListInstanceGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListInstanceGroups.paginate)
         """
 
 
 class ListInstancesPaginator(Boto3Paginator):
     """
-    [Paginator.ListInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListInstances)
+    [Paginator.ListInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListInstances)
     """
 
     def paginate(
@@ -147,26 +149,26 @@ class ListInstancesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListInstancesOutputTypeDef]:
         """
-        [ListInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListInstances.paginate)
+        [ListInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListInstances.paginate)
         """
 
 
 class ListSecurityConfigurationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSecurityConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListSecurityConfigurations)
+    [Paginator.ListSecurityConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListSecurityConfigurations)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListSecurityConfigurationsOutputTypeDef]:
         """
-        [ListSecurityConfigurations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListSecurityConfigurations.paginate)
+        [ListSecurityConfigurations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListSecurityConfigurations.paginate)
         """
 
 
 class ListStepsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSteps documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListSteps)
+    [Paginator.ListSteps documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListSteps)
     """
 
     def paginate(
@@ -187,5 +189,5 @@ class ListStepsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListStepsOutputTypeDef]:
         """
-        [ListSteps.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR.Paginator.ListSteps.paginate)
+        [ListSteps.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.36/reference/services/emr.html#EMR.Paginator.ListSteps.paginate)
         """
