@@ -9,14 +9,15 @@ Usage::
     data: ApplicationTypeDef = {...}
     ```
 """
-from datetime import datetime
 import sys
-from typing import Dict, List
+from datetime import datetime
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -42,7 +43,6 @@ __all__ = (
     "ClusterTypeDef",
     "CommandTypeDef",
     "ComputeLimitsTypeDef",
-    "ConfigurationTypeDef",
     "EbsBlockDeviceConfigTypeDef",
     "EbsBlockDeviceTypeDef",
     "EbsConfigurationTypeDef",
@@ -77,6 +77,7 @@ __all__ = (
     "KeyValueTypeDef",
     "ManagedScalingPolicyTypeDef",
     "MetricDimensionTypeDef",
+    "OnDemandProvisioningSpecificationTypeDef",
     "PlacementTypeTypeDef",
     "PortRangeTypeDef",
     "ScalingActionTypeDef",
@@ -107,6 +108,7 @@ __all__ = (
     "DescribeJobFlowsOutputTypeDef",
     "DescribeSecurityConfigurationOutputTypeDef",
     "DescribeStepOutputTypeDef",
+    "ConfigurationTypeDef",
     "GetBlockPublicAccessConfigurationOutputTypeDef",
     "GetManagedScalingPolicyOutputTypeDef",
     "InstanceFleetModifyConfigTypeDef",
@@ -335,7 +337,7 @@ ClusterTypeDef = TypedDict(
         "ServiceRole": str,
         "NormalizedInstanceHours": int,
         "MasterPublicDnsName": str,
-        "Configurations": List["ConfigurationTypeDef"],
+        "Configurations": List[Dict[str, Any]],
         "SecurityConfiguration": str,
         "AutoScalingRole": str,
         "ScaleDownBehavior": Literal["TERMINATE_AT_INSTANCE_HOUR", "TERMINATE_AT_TASK_COMPLETION"],
@@ -363,7 +365,9 @@ _RequiredComputeLimitsTypeDef = TypedDict(
     },
 )
 _OptionalComputeLimitsTypeDef = TypedDict(
-    "_OptionalComputeLimitsTypeDef", {"MaximumOnDemandCapacityUnits": int}, total=False
+    "_OptionalComputeLimitsTypeDef",
+    {"MaximumOnDemandCapacityUnits": int, "MaximumCoreCapacityUnits": int},
+    total=False,
 )
 
 
@@ -371,16 +375,6 @@ class ComputeLimitsTypeDef(_RequiredComputeLimitsTypeDef, _OptionalComputeLimits
     pass
 
 
-ConfigurationTypeDef = TypedDict(
-    "ConfigurationTypeDef",
-    {
-        "Classification": str,
-        "Configurations": List["ConfigurationTypeDef"],
-        "Properties": Dict[str, str],
-    },
-    total=False,
-)
-
 _RequiredEbsBlockDeviceConfigTypeDef = TypedDict(
     "_RequiredEbsBlockDeviceConfigTypeDef", {"VolumeSpecification": "VolumeSpecificationTypeDef"}
 )
@@ -475,7 +469,11 @@ class InstanceFleetConfigTypeDef(
 
 InstanceFleetProvisioningSpecificationsTypeDef = TypedDict(
     "InstanceFleetProvisioningSpecificationsTypeDef",
-    {"SpotSpecification": "SpotProvisioningSpecificationTypeDef"},
+    {
+        "SpotSpecification": "SpotProvisioningSpecificationTypeDef",
+        "OnDemandSpecification": "OnDemandProvisioningSpecificationTypeDef",
+    },
+    total=False,
 )
 
 InstanceFleetStateChangeReasonTypeDef = TypedDict(
@@ -540,7 +538,7 @@ _OptionalInstanceGroupConfigTypeDef = TypedDict(
         "Name": str,
         "Market": Literal["ON_DEMAND", "SPOT"],
         "BidPrice": str,
-        "Configurations": List["ConfigurationTypeDef"],
+        "Configurations": List[Dict[str, Any]],
         "EbsConfiguration": "EbsConfigurationTypeDef",
         "AutoScalingPolicy": "AutoScalingPolicyTypeDef",
     },
@@ -650,9 +648,9 @@ InstanceGroupTypeDef = TypedDict(
         "RequestedInstanceCount": int,
         "RunningInstanceCount": int,
         "Status": "InstanceGroupStatusTypeDef",
-        "Configurations": List["ConfigurationTypeDef"],
+        "Configurations": List[Dict[str, Any]],
         "ConfigurationsVersion": int,
-        "LastSuccessfullyAppliedConfigurations": List["ConfigurationTypeDef"],
+        "LastSuccessfullyAppliedConfigurations": List[Dict[str, Any]],
         "LastSuccessfullyAppliedConfigurationsVersion": int,
         "EbsBlockDevices": List["EbsBlockDeviceTypeDef"],
         "EbsOptimized": bool,
@@ -715,7 +713,7 @@ _OptionalInstanceTypeConfigTypeDef = TypedDict(
         "BidPrice": str,
         "BidPriceAsPercentageOfOnDemandPrice": float,
         "EbsConfiguration": "EbsConfigurationTypeDef",
-        "Configurations": List["ConfigurationTypeDef"],
+        "Configurations": List[Dict[str, Any]],
     },
     total=False,
 )
@@ -753,7 +751,7 @@ InstanceTypeSpecificationTypeDef = TypedDict(
         "WeightedCapacity": int,
         "BidPrice": str,
         "BidPriceAsPercentageOfOnDemandPrice": float,
-        "Configurations": List["ConfigurationTypeDef"],
+        "Configurations": List[Dict[str, Any]],
         "EbsBlockDevices": List["EbsBlockDeviceTypeDef"],
         "EbsOptimized": bool,
     },
@@ -880,6 +878,10 @@ MetricDimensionTypeDef = TypedDict(
     "MetricDimensionTypeDef", {"Key": str, "Value": str}, total=False
 )
 
+OnDemandProvisioningSpecificationTypeDef = TypedDict(
+    "OnDemandProvisioningSpecificationTypeDef", {"AllocationStrategy": Literal["lowest-price"]}
+)
+
 PlacementTypeTypeDef = TypedDict(
     "PlacementTypeTypeDef", {"AvailabilityZone": str, "AvailabilityZones": List[str]}, total=False
 )
@@ -980,7 +982,9 @@ _RequiredSpotProvisioningSpecificationTypeDef = TypedDict(
     },
 )
 _OptionalSpotProvisioningSpecificationTypeDef = TypedDict(
-    "_OptionalSpotProvisioningSpecificationTypeDef", {"BlockDurationMinutes": int}, total=False
+    "_OptionalSpotProvisioningSpecificationTypeDef",
+    {"BlockDurationMinutes": int, "AllocationStrategy": Literal["capacity-optimized"]},
+    total=False,
 )
 
 
@@ -1153,6 +1157,12 @@ DescribeStepOutputTypeDef = TypedDict(
     "DescribeStepOutputTypeDef", {"Step": "StepTypeDef"}, total=False
 )
 
+ConfigurationTypeDef = TypedDict(
+    "ConfigurationTypeDef",
+    {"Classification": str, "Configurations": List[Dict[str, Any]], "Properties": Dict[str, str]},
+    total=False,
+)
+
 GetBlockPublicAccessConfigurationOutputTypeDef = TypedDict(
     "GetBlockPublicAccessConfigurationOutputTypeDef",
     {
@@ -1192,7 +1202,7 @@ _OptionalInstanceGroupModifyConfigTypeDef = TypedDict(
         "InstanceCount": int,
         "EC2InstanceIdsToTerminate": List[str],
         "ShrinkPolicy": "ShrinkPolicyTypeDef",
-        "Configurations": List["ConfigurationTypeDef"],
+        "Configurations": List[Dict[str, Any]],
     },
     total=False,
 )
